<?php

namespace ext\crudactions;

class Delete extends Base {

    /**
     * Raises onBeforeDelete event. The event provides the model instance used.
     *
     * @param Event $event
     */
    public function onBeforeDelete(Event $event) {
        $this->raiseEvent('onBeforeDelete', $event);
    }

    /**
     * Raises onAfterDelete event. The event provides the model instance used.
     *
     * @param Event $event
     */
    public function onAfterDelete(Event $event) {
        $this->raiseEvent('onAfterDelete', $event);
    }

    public function run() {
        if (empty($_GET['id']))
            throw new \CHttpException(404, 'The requested page does not exist.');
        $model = $this->loadModel($_GET['id']);

        // we only allow deletion via POST request
        if (!\Yii::app()->request->isPostRequest)
            throw new \CHttpException(400, 'Invalid request. Please do not repeat this request again.');

        $this->onBeforeDelete(new Event($model, $this));
        $this->onAfterDelete(new Event($model, $this, $model->delete()));

        // if AJAX request (triggered by deletion via admin grid view), we should not redirect the browser
        if (!isset($_GET['ajax']))
            $this->getController()->redirect(array('index'));
    }

}